@@ -1,7 +1,7 @@
 use v5.14;
 use warnings;
 
-package Datify v0.19.045;
+package Datify v0.20.045;
 # ABSTRACT: Simple stringification of data.
 
 
@@ -11,7 +11,7 @@ use overload ();        #qw( Method Overloaded );
 use Carp         ();    #qw( carp croak );
 use List::Util   ();    #qw( reduce sum );
 use Scalar::Util ();    #qw( blessed looks_like_number refaddr reftype );
-use String::Tools v0.18.277 ();    #qw( stringify subst );
+use String::Tools v0.18.277 ();    #qw( stitch stringify subst );
 use Sub::Util      1.40     ();    #qw( subname );
 
 
@@ -31,11 +31,62 @@ sub new {
 
 
 
+### Accessor ###
+
+
+
+
+sub exists {
+    my $self = shift;
+    return unless my $count = scalar(@_);
+
+    my $SETTINGS = $self->_settings;
+    if ( Scalar::Util::blessed($self) ) {
+        return $count == 1
+            ?      exists $self->{ $_[0] }     && $self
+                || exists $SETTINGS->{ $_[0] } && $SETTINGS
+            : map {
+                   exists $self->{ $_ }        && $self
+                || exists $SETTINGS->{ $_ }    && $SETTINGS
+            } @_;
+    } else {
+        return
+            $count == 1 ? exists $SETTINGS->{ $_[0] } && $SETTINGS
+            :       map { exists $SETTINGS->{ $_ }    && $SETTINGS } @_;
+    }
+}
+
+
+
+sub _get_setting {
+    my $setting = $_[0]->exists( local $_ = $_[1] );
+    return $setting ? $setting->{$_} : do {
+        Carp::carp( 'Unknown key ', $_ )
+            unless $_[0]->_internal(1);
+        undef
+    };
+}
+sub get {
+    my $self  = shift;
+    my $count = scalar(@_);
+
+    if ( defined( my $class = Scalar::Util::blessed($self) ) ) {
+        return
+              $count == 0 ? ( %{ $self->_settings }, %$self )
+            : $count == 1 ? $self->_get_setting(shift)
+            :         map { $self->_get_setting($_) } @_;
+    } else {
+        return
+              $count == 0 ? %{ $self->_settings }
+            : $count == 1 ? $self->_get_setting(shift)
+            :         map { $self->_get_setting($_) } @_;
+    }
+}
+
+
 ### Setter ###
 
 
-my %SETTINGS;
-
 sub set {
     my $self = shift;
     return $self unless @_;
@@ -49,19 +100,18 @@ sub set {
         $return = 0;
     } else {
         $class  = $self;
-        $self   = \%SETTINGS;
+        $self   = $class->_settings;
         $return = 1;
     }
 
     delete $self->{keyword_set} if ( $set{keywords} );
-    delete $self->{"tr$_"} for grep { exists $set{"quote$_"} } ( 1, 2, 3 );
+    delete $self->{"_tr$_"} for grep { exists $set{"quote$_"} } ( 1, 2, 3 );
 
-    my $internal = $class->isa( scalar caller );
+    my $internal = $class->_internal;
     while ( my ( $k, $v ) = each %set ) {
         Carp::carp( 'Unknown key ', $k )
-            unless $internal
-            || exists $self->{$k}
-            || exists $SETTINGS{$k};
+            unless $internal || $class->exists($k);
+        study($v) if defined($v) && !ref($v);
         $self->{$k} = $v;
     }
 
@@ -70,46 +120,6 @@ sub set {
 
 
 
-### Accessor ###
-
-
-sub get {
-    my $self  = shift;
-    my $count = scalar(@_);
-
-    if ( defined( Scalar::Util::blessed($self) ) ) {
-        return
-              $count == 0 ? $self->hashkeyvals( { %SETTINGS, %$self } )
-            : $count == 1 ?
-                exists  $self->{ $_[0] }
-                    ?   $self->{ $_[0] }
-                    : $SETTINGS{ $_[0] }
-            : map { exists $self->{$_} ? $self->{$_} : $SETTINGS{$_} } @_;
-    } else {
-        return
-              $count == 0 ? $self->hashkeyvals( \%SETTINGS )
-            : $count == 1 ? $SETTINGS{ $_[0] }
-            :               @SETTINGS{@_};
-    }
-}
-
-
-sub exists {
-    my $self = shift;
-    return unless my $count = scalar(@_);
-
-    if ( Scalar::Util::blessed($self) ) {
-        return $count == 1
-            ? do {  exists $self->{ $_[0] } || exists $SETTINGS{ $_[0] } }
-            : map { exists $self->{ $_ }    || exists $SETTINGS{ $_ } } @_;
-    } else {
-        return
-            $count == 1 ? exists $SETTINGS{ $_[0] }
-            :       map { exists $SETTINGS{ $_ } } @_;
-    }
-}
-
-
 
 sub add_handler {
     my $self = &self;
@@ -312,9 +322,9 @@ __PACKAGE__->set(
     # String options
     quote   => undef,   # Auto
     quote1  => "'",
-    #tr1     => q!tr\\'\\'\\!,
+    #_tr1    => q!tr\\'\\'\\!,
     quote2  => '"',
-    #tr2     => q!tr\\"\\"\\!,
+    #_tr2    => q!tr\\"\\"\\!,
     q1      => 'q',
     q2      => 'qq',
     sigils  => '$@',
@@ -379,14 +389,14 @@ sub stringify {
     return $self->stringify2($_)
         if ( ( $longstr && $longstr < length() ) || ( $also && /[$also]/ ) );
 
-    my $tr1 = $self->get('tr1');
-    $self = $self->set( tr1 => $tr1 = "tr\\$quote1\\$quote1\\" )
+    my $tr1 = $self->get('_tr1');
+    $self = $self->set( _tr1 => $tr1 = "tr\\$quote1\\$quote1\\" )
         if ( not $tr1 );
     my $single_quotes = eval $tr1 // die $@;
     return $self->stringify1($_) unless $single_quotes;
 
-    my ( $sigils, $tr2 ) = $self->get(qw( sigils tr2 ));
-    $self = $self->set( tr2 => $tr2 = "tr\\$quote2$sigils\\$quote2$sigils\\" )
+    my ( $sigils, $tr2 ) = $self->get(qw( sigils _tr2 ));
+    $self = $self->set( _tr2 => $tr2 = "tr\\$quote2$sigils\\$quote2$sigils\\" )
         if ( not $tr2 );
     my $double_quotes = eval $tr2 // die $@;
     return $self->stringify2($_) unless $double_quotes;
@@ -468,6 +478,12 @@ sub numify {
 ### Scalar ###
 
 
+__PACKAGE__->set(
+    # Scalar options
+    scalar_ref  => '\do{1;$_}',
+);
+
+
 sub scalarify {
     my $self = &self;
     local $_ = shift if @_;
@@ -516,7 +532,8 @@ sub _scalarify {
         : $ref eq 'REF'    ? $self->refify($$_)
         : $ref eq 'REGEXP' ? $self->regexpify($_)        # ???
         : do {
-            my $reference = $self->get('reference');
+            my $reference = $self->get( lc($ref) . '_reference' )
+                ||          $self->get('reference');
 
               $ref eq 'GLOB'    ? _subst( $reference, $self->globify($$_) )
             : $ref eq 'LVALUE'  ? _subst( $reference, $self->lvalueify($$_) )
@@ -573,7 +590,7 @@ sub vstringify {
 __PACKAGE__->set(
     # Regexp options
     quote3  => '/',
-    #tr3     => q!tr\\/\\/\\!,
+    #_tr3    => q!tr\\/\\/\\!,
     q3      => 'qr',
 
     encode3 => {
@@ -599,8 +616,8 @@ sub regexpify {
     local $_ = shift if @_;
     local $@ = undef;
 
-    my ( $quote3, $tr3 ) = $self->get(qw( quote3 tr3 ));
-    $self = $self->set( tr3 => $tr3 = "tr\\$quote3\\$quote3\\" )
+    my ( $quote3, $tr3 ) = $self->get(qw( quote3 _tr3 ));
+    $self = $self->set( _tr3 => $tr3 = "tr\\$quote3\\$quote3\\" )
         if ( not $tr3 );
     my $quoter = eval $tr3 // die $@;
     my ( $open, $close )
@@ -696,32 +713,29 @@ sub keyify {
 
 
 
-sub _cmp_;
+sub keysort($$);
 BEGIN {
-    if ( $^V >= v5.16.0 ) {
-        eval <<'END_CMP';
-sub _cmp_ {
-    return CORE::fc( $_[0] ) cmp CORE::fc( $_[1] )
-        ||           $_[0]   cmp           $_[1];
-}
-END_CMP
-    } else {
-        eval <<'END_CMP';
-sub _cmp_ { $_[0] cmp $_[1] }
-END_CMP
-    }
+    no warnings 'qw';
+    my $keysort = String::Tools::stitch(qw(
+        sub keysort($$) {
+            my ( $a, $b ) = @_;
+            my $numa = Datify->is_numeric($a);
+            my $numb = Datify->is_numeric($b);
+            return
+                  $numa && $numb ? $a <=> $b
+                : $numa          ? -1
+                :          $numb ?        +1
+                :                  $a_cmp__b
+                ;
+        }
+    ));
+    my $a_cmp__b
+        = ( $^V >= v5.16.0 ? 'CORE::fc($a) cmp CORE::fc($b) || ' : '' )
+        . '$a cmp $b';
+    $keysort = String::Tools::subst( $keysort, a_cmp__b => $a_cmp__b );
+    eval($keysort) or $@ and die $@;
 }
 
-sub keysort($$) {
-    my ( $a, $b ) = @_;
-    my $numa = Datify->is_numeric($a);
-    my $numb = Datify->is_numeric($b);
-       $numa && $numb ? $a <=> $b
-    :  $numa          ? -1
-    :           $numb ?        +1
-    :  _cmp_( $a, $b )
-    ;
-}
 
 
 sub hashkeys {
@@ -1004,13 +1018,51 @@ sub globify   {
     return $name;
 }
 
-### Internal ###
-### Do not use these methods outside of this package,
+
+
+sub beautify {
+    my $self = &self;
+    my ( $method, @params ) = @_;
+
+    $method = $self->can($method) || die "Cannot $method";
+
+    if ( my $beauty = $self->get('beautify') ) {
+        return $beauty->( $self->$method(@params) );
+    } else {
+        return $self->$method(@params);
+    }
+}
+
+### Private Methods & Settings ###
+### Do not use these methods & settings outside of this package,
 ### they are subject to change or disappear at any time.
+sub class {
+    return scalar caller unless @_;
+    my $caller = caller;
+    my $class;
+    if ( defined( $class = Scalar::Util::blessed( $_[0] ) )
+        || ( !ref( $_[0] ) && length( $class = $_[0] ) ) )
+    {
+        if ( $class->isa($caller) ) {
+            shift;
+            return $class;
+        }
+    }
+    return $caller;
+}
 sub self {
     my $self = shift;
     return defined( Scalar::Util::blessed($self) ) ? $self : $self->new();
 }
+sub _internal { return $_[0]->isa( scalar caller( 1 + ( $_[1] // 0 ) ) ) }
+sub _private {
+    Carp::croak('Illegal use of private method') unless $_[0]->_internal(1);
+}
+sub _settings() {
+    &_private;
+    \state %SETTINGS;
+}
+
 sub _nameify {
     local $_ = shift if @_;
     s/::/_/g;
@@ -1019,11 +1071,11 @@ sub _nameify {
 sub _find_handler {
     my $self  = shift;
     my $class = shift;
+
     my $isa = mro::get_linear_isa($class);
     foreach my $c (@$isa) {
-        if ( my $code = $self->can( _nameify($c) ) ) {
-            return $code;
-        }
+        next unless my $code = $self->can( _nameify($c) );
+        return $code;
     }
     return;
 }
@@ -1220,7 +1272,7 @@ sub _pop_position {
     my $self = shift;
     return pop @{ $self->{_position} };
 }
-sub _name_and_position {
+sub _cache_position {
     my $self = shift;
 
     my $nest = $self->get('nested') // $self->get('dereference');
@@ -1258,7 +1310,7 @@ sub _cache_add {
 
     return $self unless my $refaddr = Scalar::Util::refaddr $ref;
     my $_cache = $self->{_cache} //= {};
-    my $entry = $_cache->{$refaddr} //= [ $self->_name_and_position ];
+    my $entry = $_cache->{$refaddr} //= [ $self->_cache_position ];
     push @$entry, $value if @$entry == $self->get('_cache_hit');
 
     return $self;
@@ -1274,10 +1326,10 @@ sub _cache_get {
         my $repr = $self->get('_cache_hit');
         return $entry->[$repr]
             // Carp::croak 'Recursive structures not allowed at ',
-                           $self->_name_and_position;
+                           $self->_cache_position;
     } else {
         # Pre-populate the cache, so that we can check for loops
-        $_cache->{$refaddr} = [ $self->_name_and_position ];
+        $_cache->{$refaddr} = [ $self->_cache_position ];
         return;
     }
 }
@@ -1316,8 +1368,8 @@ Datify - Simple stringification of data.
 
 =head1 DESCRIPTION
 
-C<Datify> is very similar to L<Data::Dumper>, except that it's
-easier to use, and has better formatting and options.
+C<Datify> is very similar to L<Data::Dumper>,
+except that it's easier to use, and has better formatting and options.
 
 =head1 OPTIONS
 
@@ -1361,10 +1413,11 @@ An example:
      my ($dest, $stderr);
      Perl::Tidy::perltidy(
          argv => [ qw(
+             --perl-best-practices
              --noprofile
              --nostandard-output
              --standard-error-output
-             --nopass-version-line
+             --nooutdent-long-lines
          ) ],
          source      => \$source,
          destination => \$dest,
@@ -1567,6 +1620,16 @@ What character to use to seperate sets of numbers.
 
 =back
 
+=head2 Scalarify options
+
+=over
+
+=item I<scalar_ref>  => B<'\do{1;$_}'>
+
+How to generate a reference to a scalar.
+
+=back
+
 =head2 LValueify options
 
 =over
@@ -1774,6 +1837,19 @@ Create a C<Datify> object with the following options.
 
 See L</OPTIONS> for a description of the options and their default values.
 
+=head2 exists( name, name, ... )
+
+Determine if values exists for one or more settings.
+
+Can be called as a class method or an object method.
+
+=head2 C<get( name, name, ... )>
+
+Get one or more existing values for one or more settings.
+If passed no names, returns all parameters and values.
+
+Can be called as a class method or an object method.
+
 =head2 C<< set( name => value, name => value, ... ) >>
 
 Change the L</OPTIONS> settings.
@@ -1789,19 +1865,6 @@ persist the change:
 
  $datify = $datify->set( ... );
 
-=head2 C<get( name, name, ... )>
-
-Get one or more existing values for one or more settings.
-If passed no names, returns all parameters and values.
-
-Can be called as a class method or an object method.
-
-=head2 exists( name, name, ... )
-
-Determine if values exists for one or more settings.
-
-Can be called as a class method or an object method.
-
 =head2 C<< add_handler( $class => \&code_ref ) >>
 
 Add a handler to handle an object of type C<$class>.
@@ -2032,6 +2095,15 @@ Returns a value that is not completely unlike value.
 Returns a representation of value.
 For normal values, remove the leading C<main::>.
 
+=head2 C<< beautify( ify => values ) >>
+
+Calls L</beautify> on the output of the C<*ify> method with C<values>.
+
+If there has been no C<beautify> method specified, returns the raw output
+from the C<*ify> method.
+
+    say( Datify->beauitfy( scalarify => $scalar ) );
+
 =head1 FUNCTIONS
 
 =head2 C<keysort($$)>
@@ -2064,7 +2136,7 @@ L<Data::Dumper>
 
 =head1 VERSION
 
-This document describes version v0.19.045 of this module.
+This document describes version v0.20.045 of this module.
 
 =head1 AUTHOR
 
